@@ -19,6 +19,7 @@
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
+// Copyright (C) 2020 Albert Astals Cid <aacid@kde.org>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -35,7 +36,7 @@
 
 /* Defines the poppler version. */
 #ifndef POPPLER_VERSION
-#define POPPLER_VERSION "0.82.0"
+#define POPPLER_VERSION "21.01.0"
 #endif
 
 /* Use single precision arithmetic in the Splash backend */
@@ -65,7 +66,7 @@
 
 /* Build against libtiff. */
 #ifndef ENABLE_LIBTIFF
-/* #undef ENABLE_LIBTIFF */
+#define ENABLE_LIBTIFF 1
 #endif
 
 /* Build against libpng. */
@@ -116,12 +117,17 @@
 #define USE_BOOST_HEADERS 1
 #endif
 
+/* Is splash backend available */
+#ifndef HAVE_SPLASH
+#define HAVE_SPLASH 1
+#endif
+
 //------------------------------------------------------------------------
 // version
 //------------------------------------------------------------------------
 
 // copyright notice
-#define popplerCopyright "Copyright 2005-2019 The Poppler Developers - http://poppler.freedesktop.org"
+#define popplerCopyright "Copyright 2005-2021 The Poppler Developers - http://poppler.freedesktop.org"
 #define xpdfCopyright "Copyright 1996-2011 Glyph & Cog, LLC"
 
 //------------------------------------------------------------------------
@@ -139,7 +145,11 @@
 //------------------------------------------------------------------------
 
 #if __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 4)
-#include <stdio.h> // __MINGW_PRINTF_FORMAT is defined in the mingw stdio.h
+#  if __cplusplus
+#  include <cstdio> // __MINGW_PRINTF_FORMAT is defined in the mingw stdio.h
+#  else
+#  include <stdio.h>
+#  endif
 #ifdef __MINGW_PRINTF_FORMAT
 #define GCC_PRINTF_FORMAT(fmt_index, va_index) \
 	__attribute__((__format__(__MINGW_PRINTF_FORMAT, fmt_index, va_index)))
